ArxivLens
ArXiv cs.LG cs.AI cs.DC

Accelerating Barnes-Hut t-SNE Algorithm by Efficient Parallelization on Multi-Core CPUs

Alexander Pivovar, Andrey Gorshkov, Narendra Chaudhary, Pavel Yakovlev

2212.11506 Published Dec 23, 2022
Read paper View PDF
More tools
At a glance AI-generated · verify against the paper

This paper presents an accelerated version of the Barnes-Hut t-SNE algorithm for multi-core CPUs, employing cache optimizations, SIMD, parallelization, and improved multithreaded execution. The new implementation, Acc-t-SNE, achieves up to 261x and 4x speedups compared to scikit-learn and daal4py, respectively.

Abstract

t-SNE remains one of the most popular embedding techniques for visualizing high-dimensional data. Most standard packages of t-SNE, such as scikit-learn, use the Barnes-Hut t-SNE (BH t-SNE) algorithm for large datasets. However, existing CPU implementations of this algorithm are inefficient. In this work, we accelerate the BH t-SNE on CPUs via cache optimizations, SIMD, parallelizing sequential steps, and improving parallelization of multithreaded steps. Our implementation (Acc-t-SNE) is up to 261x and 4x faster than scikit-learn and the state-of-the-art BH t-SNE implementation from daal4py, respectively, on a 32-core Intel(R) Icelake cloud instance.

AI Key Findings

Get AI-generated insights about this paper's methodology, results, significance, and more — available when analysis has been generated.

Paper preview View the original document Preview of the original paper

How to Cite This Paper

Reference manager: RIS EndNote

Discussion 0

This website uses cookies to ensure you get the best experience. Learn more